import { Component, OnInit } from "@angular/core"

@Component({
    selector: "livedb-admin",
    templateUrl: "livedb.component.html"
})
export class LiveDBComponent implements OnInit {
    
    ngOnInit() {
    
    }
}
